@@ -72,6 +72,27 @@ class CustomerOrderBatchHandler(BatchHandler):
                                    'new_order_requires_customer',
                                    default=False)
 
+    def allow_contact_info_choice(self):
+        """
+        Returns a boolean indicating whether the user is allowed at
+        all, to choose from existing contact info options for the
+        customer, vs. they just have to go with whatever the handler
+        auto-provides.
+        """
+        return self.config.getbool('rattail.custorders',
+                                   'new_orders.allow_contact_info_choice',
+                                   default=True)
+
+    def should_restrict_contact_info(self):
+        """
+        Returns a boolean indicating whether contact info should be
+        "restricted" - i.e. user can only choose from existing contact
+        info and cannot override by e.g. entering a new phone number.
+        """
+        return self.config.getbool('rattail.custorders',
+                                   'new_orders.restrict_contact_info',
+                                   default=False)
+
     def assign_contact(self, batch, customer=None, person=None, **kwargs):
         """
         Assign the customer and/or person "contact" for the order.
@@ -95,6 +116,9 @@ class CustomerOrderBatchHandler(BatchHandler):
         batch.customer = customer
         batch.person = person
 
+        # cache contact name
+        batch.contact_name = self.get_contact_display(batch)
+
         # update phone/email per new contact
         batch.phone_number = None
         batch.email_address = None
@@ -105,9 +129,123 @@ class CustomerOrderBatchHandler(BatchHandler):
             batch.phone_number = person.first_phone_number()
             batch.email_address = person.first_email_address()
 
+        # always reset "add to customer" flags
+        batch.clear_param('add_phone_number')
+        batch.clear_param('add_email_address')
+
         session = self.app.get_session(batch)
         session.flush()
-        session.refresh(batch)
+
+    def get_contact(self, batch):
+        """
+        Should return the contact record (i.e. Customer or Person) for
+        the batch.
+        """
+        customer_required = self.new_order_requires_customer()
+
+        if customer_required:
+            return batch.customer
+        else:
+            return batch.person
+
+    def get_contact_id(self, batch):
+        """
+        Should return contact ID for the batch, i.e. customer ID.
+        """
+        contact = self.get_contact(batch)
+        if isinstance(contact, model.Customer):
+            return contact.id
+
+    def get_contact_display(self, batch):
+        """
+        Should return contact display text for the batch,
+        i.e. customer name.
+        """
+        contact = self.get_contact(batch)
+        if contact:
+            return six.text_type(contact)
+
+        pending = batch.pending_customer
+        if pending:
+            return six.text_type(pending)
+
+    def get_contact_phones(self, batch):
+        """
+        Retrieve all phone records on file for the batch contact, to
+        be presented as options for user to choose from when making a
+        new order.
+        """
+        phones = []
+        contact = self.get_contact(batch)
+        if contact:
+            phones = contact.phones
+
+        return [self.normalize_phone(phone)
+                for phone in phones]
+
+    def normalize_phone(self, phone):
+        """
+        Normalize the given phone record to simple data dict, for
+        passing around via JSON etc.
+        """
+        return {
+            'uuid': phone.uuid,
+            'type': phone.type,
+            'number': phone.number,
+            'preference': phone.preference,
+            'preferred': phone.preference == 1,
+        }
+
+    def get_contact_emails(self, batch):
+        """
+        Retrieve all email records on file for the batch contact, to
+        be presented as options for user to choose from when making a
+        new order.
+
+        Note that the default logic will exclude invalid email addresses.
+        """
+        emails = []
+        contact = self.get_contact(batch)
+        if contact:
+            emails = contact.emails
+
+        # exclude invalid
+        emails = [email for email in emails
+                  if not email.invalid]
+
+        return [self.normalize_email(email)
+                for email in emails]
+
+    def normalize_email(self, email):
+        """
+        Normalize the given email record to simple data dict, for
+        passing around via JSON etc.
+        """
+        return {
+            'uuid': email.uuid,
+            'type': email.type,
+            'address': email.address,
+            'invalid': email.invalid,
+            'preference': email.preference,
+            'preferred': email.preference == 1,
+        }
+
+    def get_contact_notes(self, batch):
+        """
+        Get extra "contact notes" which should be made visible to the
+        user who is entering the new order.
+        """
+        notes = []
+
+        invalid = False
+        contact = self.get_contact(batch)
+        if contact:
+            invalid = [email for email in contact.emails
+                       if email.invalid]
+        if invalid:
+            notes.append("Customer has one or more invalid email addresses on file.")
+
+        return notes
 
     def unassign_contact(self, batch, **kwargs):
         """
@@ -115,13 +253,59 @@ class CustomerOrderBatchHandler(BatchHandler):
         """
         batch.customer = None
         batch.person = None
+        batch.contact_name = None
         batch.phone_number = None
         batch.email_address = None
 
+        # always reset "add to customer" flags
+        batch.clear_param('add_phone_number')
+        batch.clear_param('add_email_address')
+
         session = self.app.get_session(batch)
         session.flush()
         session.refresh(batch)
 
+    def validate_pending_customer_data(self, batch, user, data):
+        pass
+
+    def update_pending_customer(self, batch, user, data):
+        model = self.model
+        people = self.app.get_people_handler()
+
+        # first validate all data
+        self.validate_pending_customer_data(batch, user, data)
+
+        # clear out any contact it may have
+        self.unassign_contact(batch)
+
+        # create pending customer if needed
+        pending = batch.pending_customer
+        if not pending:
+            pending = model.PendingCustomer()
+            pending.user = user
+            pending.status_code = self.enum.PENDING_CUSTOMER_STATUS_PENDING
+            batch.pending_customer = pending
+
+        # update pending customer info
+        if 'first_name' in data:
+            pending.first_name = data['first_name']
+        if 'last_name' in data:
+            pending.last_name = data['last_name']
+        if 'display_name' in data:
+            pending.display_name = data['display_name']
+        else:
+            pending.display_name = people.normalize_full_name(pending.first_name,
+                                                              pending.last_name)
+        if 'phone_number' in data:
+            pending.phone_number = self.app.format_phone_number(data['phone_number'])
+        if 'email_address' in data:
+            pending.email_address = data['email_address']
+
+        # also update the batch w/ contact info
+        batch.contact_name = pending.display_name
+        batch.phone_number = pending.phone_number
+        batch.email_address = pending.email_address
+
     def get_case_size_for_product(self, product):
         if product.case_size:
             return product.case_size
@@ -339,14 +523,66 @@ class CustomerOrderBatchHandler(BatchHandler):
 
     def execute(self, batch, user=None, progress=None, **kwargs):
         """
-        Default behavior here will simply create a new (proper) Customer Order
-        based on the batch contents.  Override as needed.
+        Default behavior here will create and return a new rattail
+        Customer Order.  It also may "add contact info" e.g. to the
+        customer record.  Override as needed.
+        """
+        order = self.make_new_order(batch, user=user, progress=progress, **kwargs)
+        self.update_contact_info(batch, user)
+        return order
+
+    def update_contact_info(self, batch, user, **kwargs):
+        """
+        Update contact info from the batch, onto the customer record.
+        """
+        if batch.get_param('add_phone_number'):
+            self.add_phone_number(batch, user)
+        if batch.get_param('add_email_address'):
+            self.add_email_address(batch, user)
+
+    def add_phone_number(self, batch, user, **kwargs):
+        """
+        Add phone number from the batch to the customer record.
+
+        Note that the default behavior does *not* do that, but instead
+        will send an email alert to configured recipient(s) with the
+        update request.
+        """
+        self.app.send_email('new_phone_requested', {
+            'user': user,
+            'user_display': user.display_name if user else "(unknown user)",
+            'contact': self.get_contact(batch),
+            'contact_id': self.get_contact_id(batch),
+            'phone_number': batch.phone_number,
+        })
+
+    def add_email_address(self, batch, user, **kwargs):
+        """
+        Add email address from the batch to the customer record.
+
+        Note that the default behavior does *not* do that, but instead
+        will send an email alert to configured recipient(s) with the
+        update request.
+        """
+        self.app.send_email('new_email_requested', {
+            'user': user,
+            'user_display': user.display_name if user else "(unknown user)",
+            'contact': self.get_contact(batch),
+            'contact_id': self.get_contact_id(batch),
+            'email_address': batch.email_address,
+        })
+
+    def make_new_order(self, batch, user=None, progress=None, **kwargs):
+        """
+        Create and return a new rattail Customer Order based on the
+        batch contents.
         """
         batch_fields = [
             'store',
             'id',
             'customer',
             'person',
+            'pending_customer',
             'phone_number',
             'email_address',
             'total_price',
