@@ -69,11 +69,28 @@ class RattailWatcher(DataSyncWatcher):
         class_names = sorted(set([c.class_name for c in changes]))
         class_names.sort(key=self.topo_sortkey)
 
-        # now create "final" list of changes, honoring class sort
-        # TODO: should we force deletions to be last? or first?
+        # now sort the changes per our ordered class sequence.  note
+        # that we must first add new/dirty changes only, then we add
+        # deleted at the end.  so that deletes are processed last, by
+        # the consumer(s), to hopefully avoid dependency issues
         final = []
+
+        # new/dirty
         for class_name in class_names:
-            for change in [c for c in changes if c.class_name == class_name]:
+            for change in [c for c in changes
+                           if c.class_name == class_name
+                           and not c.deleted]:
+                final.append((change.uuid,
+                              model.DataSyncChange(
+                                  payload_type=class_name,
+                                  payload_key=change.instance_uuid,
+                                  deletion=change.deleted)))
+
+        # deleted
+        for class_name in class_names:
+            for change in [c for c in changes
+                           if c.class_name == class_name
+                           and c.deleted]:
                 final.append((change.uuid,
                               model.DataSyncChange(
                                   payload_type=class_name,
