@@ -34,8 +34,15 @@ from .people import (Person, PersonNote,
                      MergePeopleRequest)
 from .users import Role, Permission, User, UserRole, UserEvent
 from .stores import Store, StorePhoneNumber, StoreEmailAddress
-from .customers import (Customer, CustomerPhoneNumber, CustomerEmailAddress, CustomerMailingAddress,
-                        CustomerGroup, CustomerGroupAssignment, CustomerPerson, CustomerNote)
+from .customers import (Customer,
+                        CustomerPhoneNumber,
+                        CustomerEmailAddress,
+                        CustomerMailingAddress,
+                        CustomerGroup,
+                        CustomerGroupAssignment,
+                        CustomerPerson,
+                        CustomerNote,
+                        PendingCustomer)
 from .members import Member, MemberPhoneNumber, MemberEmailAddress, MemberMailingAddress
 
 from .org import Department, Subdepartment, Category, Family, ReportCode, DepositLink
