@@ -198,6 +198,24 @@ class BatchMixin(object):
             self.__class__.__name__,
             self.id_str if self.id else "(new)")
 
+    def get_param(self, key):
+        if self.params is not None:
+            return self.params.get(key)
+
+    def set_param(self, key, value):
+        # TODO: why must we reconstruct params each time instead of
+        # just modifying in place?
+        params = dict(self.params or {})
+        params[key] = value
+        self.params = params
+
+    def clear_param(self, key):
+        # TODO: why must we reconstruct params each time instead of
+        # just modifying in place?
+        params = dict(self.params or {})
+        params.pop(key, None)
+        self.params = params
+
     # TODO: deprecate/remove this?
     def add_row(self, row):
         """
