@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -40,18 +40,19 @@ class LabelBatch(BatchMixin, Base):
     """
     Primary data model for label batches.
     """
-    __tablename__ = 'label_batch'
+    __tablename__ = 'batch_labels'
     __batchrow_class__ = 'LabelBatchRow'
     batch_key = 'labels'
     model_title = "Label Batch"
+    model_title_plural = "Label Batches"
 
     @declared_attr
     def __table_args__(cls):
         return cls.__default_table_args__() + (
             sa.ForeignKeyConstraint(['handheld_batch_uuid'], ['batch_handheld.uuid'],
-                                    name='label_batch_fk_handheld_batch'),
+                                    name='batch_labels_fk_handheld_batch'),
             sa.ForeignKeyConstraint(['label_profile_uuid'], ['label_profile.uuid'],
-                                    name='label_batch_fk_label_profile'),
+                                    name='batch_labels_fk_label_profile'),
         )
 
     handheld_batch_uuid = sa.Column(sa.String(length=32), nullable=True)
@@ -92,14 +93,14 @@ class LabelBatch(BatchMixin, Base):
 
 class LabelBatchFromHandheld(Base):
     """
-    Primary data model for label batches.
+    Represents association betwewn a handheld and label batch.
     """
-    __tablename__ = 'label_batch_handheld'
+    __tablename__ = 'batch_labels_handheld'
     __table_args__ = (
-        sa.ForeignKeyConstraint(['batch_uuid'], ['label_batch.uuid'],
-                                name='label_batch_handheld_fk_batch'),
+        sa.ForeignKeyConstraint(['batch_uuid'], ['batch_labels.uuid'],
+                                name='batch_labels_handheld_fk_batch'),
         sa.ForeignKeyConstraint(['handheld_uuid'], ['batch_handheld.uuid'],
-                                name='label_batch_handheld_fk_handheld'),
+                                name='batch_labels_handheld_fk_handheld'),
     )
 
     uuid = uuid_column()
@@ -144,14 +145,14 @@ class LabelBatchRow(ProductBatchRowMixin, Base):
     """
     Row of data within a label batch.
     """
-    __tablename__ = 'label_batch_row'
+    __tablename__ = 'batch_labels_row'
     __batch_class__ = LabelBatch
 
     @declared_attr
     def __table_args__(cls):
         return cls.__default_table_args__() + (
             sa.ForeignKeyConstraint(['label_profile_uuid'], ['label_profile.uuid'],
-                                    name='label_batch_row_fk_label_profile'),
+                                    name='batch_labels_row_fk_label_profile'),
         )
 
     STATUS_OK                           = 1
