@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -216,6 +216,9 @@ class PurchaseBatchRow(BatchRowMixin, PurchaseItemBase, Base):
     STATUS_CASE_QUANTITY_DIFFERS        = 10
     STATUS_TRUCKDUMP_PARTCLAIMED        = 11
     STATUS_OUT_OF_STOCK                 = 12
+    STATUS_ON_PO_NOT_INVOICE            = 13
+    STATUS_ON_INVOICE_NOT_PO            = 14
+    STATUS_COST_INCREASE                = 15
 
     STATUS = {
         STATUS_OK                       : "ok",
@@ -230,6 +233,9 @@ class PurchaseBatchRow(BatchRowMixin, PurchaseItemBase, Base):
         STATUS_TRUCKDUMP_CLAIMED        : "fully claimed by child(ren)",
         STATUS_TRUCKDUMP_OVERCLAIMED    : "OVER claimed by child(ren)",
         STATUS_OUT_OF_STOCK             : "out of stock",
+        STATUS_ON_PO_NOT_INVOICE        : "on PO but not on invoice",
+        STATUS_ON_INVOICE_NOT_PO        : "on invoice but not on PO",
+        STATUS_COST_INCREASE            : "cost increase",
     }
 
     item_entry = sa.Column(sa.String(length=32), nullable=True, doc="""
