@@ -35,7 +35,7 @@ from sqlalchemy.ext.orderinglist import ordering_list
 from sqlalchemy.ext.declarative import declared_attr
 
 from rattail.db.model import Base, uuid_column
-from rattail.db.model import Store, Customer, Person, Product, User, Note
+from rattail.db.model import Store, Customer, PendingCustomer, Person, Product, User, Note
 from rattail.db.types import GPCType
 
 
@@ -58,6 +58,8 @@ class CustomerOrderBase(object):
                                     name='{}_fk_customer'.format(table_name)),
             sa.ForeignKeyConstraint(['person_uuid'], ['person.uuid'],
                                     name='{}_fk_person'.format(table_name)),
+            sa.ForeignKeyConstraint(['pending_customer_uuid'], ['pending_customer.uuid'],
+                                    name='{}_fk_pending_customer'.format(table_name)),
         )
 
     store_uuid = sa.Column(sa.String(length=32), nullable=True)
@@ -90,6 +92,21 @@ class CustomerOrderBase(object):
             Reference to the person to whom the order applies.
             """)
 
+    pending_customer_uuid = sa.Column(sa.String(length=32), nullable=True)
+
+    @declared_attr
+    def pending_customer(cls):
+        return orm.relationship(
+            PendingCustomer,
+            doc="""
+            Reference to the *pending* customer account for the order,
+            if applicable.
+            """)
+
+    contact_name = sa.Column(sa.String(length=100), nullable=True, doc="""
+    Cached display name for the contact (customer).
+    """)
+
     phone_number = sa.Column(sa.String(length=20), nullable=True, doc="""
     Customer contact phone number for sake of this order.
     """)
