@@ -104,11 +104,11 @@ class Employee(Base):
     def customers(self):
         return self.person.customers
 
-    def only_customer(self):
+    def only_customer(self, require=True):
         """
         Convenience method which invokes ``self.person.only_customer()``
         """
-        return self.person.only_customer()
+        return self.person.only_customer(require=require)
 
     def add_email_address(self, address, type='Home'):
         email = EmployeeEmailAddress(address=address, type=type)
