@@ -232,6 +232,15 @@ MESSAGE_STATUS = {
 }
 
 
+PENDING_CUSTOMER_STATUS_PENDING         = 1
+PENDING_CUSTOMER_STATUS_READY           = 2
+
+PENDING_CUSTOMER_STATUS = OrderedDict([
+    (PENDING_CUSTOMER_STATUS_PENDING,           "pending"),
+    (PENDING_CUSTOMER_STATUS_READY,             "ready"),
+])
+
+
 PHONE_TYPE_HOME                 = 'home'
 PHONE_TYPE_MOBILE               = 'mobile'
 PHONE_TYPE_OTHER                = 'other'
