@@ -26,7 +26,10 @@ Base classes for importers which have file(s) as source data
 
 from __future__ import unicode_literals, absolute_import
 
+import os
+
 from rattail import importing
+from rattail.excel import ExcelReader
 
 
 class FromFile(importing.Importer):
@@ -35,13 +38,40 @@ class FromFile(importing.Importer):
     """
 
     def setup(self):
+        if not hasattr(self, 'input_file_path'):
+            self.input_file_path = self.get_input_file_path()
         self.open_input_file()
 
     def teardown(self):
         self.close_input_file()
 
+    def get_input_file_path(self):
+        return os.path.join(self.input_dir,
+                            self.get_input_file_name())
+
+    def get_input_file_name(self):
+        raise NotImplementedError
+
     def open_input_file(self):
         raise NotImplementedError
 
     def close_input_file(self):
         raise NotImplementedError
+
+
+class FromExcelFile(FromFile):
+    """
+    Base class for importers which get their data from Excel file.
+    """
+
+    def get_input_file_name(self):
+        return '{}.xlsx'.format(self.model_name)
+
+    def open_input_file(self):
+        self.excel_reader = ExcelReader(self.input_file_path)
+
+    def close_input_file(self):
+        pass
+
+    def get_host_objects(self):
+        return self.excel_reader.read_rows()
