@@ -109,6 +109,116 @@ class PeopleHandler(GenericHandler):
             person.display_name = self.normalize_full_name(
                 person.first_name, person.last_name)
 
+    def add_phone(self, person, number, type='Home', preferred=False, **kwargs):
+        """
+        Add a phone record for the person.
+
+        :param person: Reference to a ``Person`` record.
+        :param number: Actual phone number to add.
+        :param type: Type of phone number to add.
+        :param preferred: Boolean indicating that this should be the
+           new "preferred" number for the person.
+        """
+        reason = self.app.phone_number_is_invalid(number)
+        if reason:
+            raise ValueError("Phone number is not valid: {}".format(reason))
+
+        phone = person.add_phone(number=self.app.format_phone_number(number),
+                                 type=type)
+        if preferred:
+            person.set_primary_phone(phone)
+
+        return phone
+
+    def update_phone(self, person, phone, **kwargs):
+        """
+        Update a phone record for the person.
+
+        :param person: Reference to a ``Person`` record.
+        :param phone: Reference to the ``PersonPhoneNumber`` record to update.
+        :param number: Actual phone number.
+        :param type: Type of phone number.
+        :param preferred: Boolean indicating that this should be the
+           new "preferred" number for the person.
+        """
+        if phone not in person.phones:
+            raise ValueError("Phone does not belong to this person.")
+
+        if 'number' in kwargs:
+            reason = self.app.phone_number_is_invalid(kwargs['number'])
+            if reason:
+                raise ValueError("Phone number is not valid: {}".format(reason))
+            phone.number = self.app.format_phone_number(kwargs['number'])
+
+        if 'type' in kwargs:
+            phone.type = kwargs['type']
+
+        if 'preferred' in kwargs:
+            if kwargs['preferred']:
+                person.set_primary_phone(phone)
+            else: # should *not* prefer this one
+                if phone.preferred and len(person.phones) > 1:
+                    # make 2nd phone the new 1st
+                    person.set_primary_phone(person.phones[1])
+
+        return phone
+
+    def add_email(self, person, address, type='Home',
+                  invalid=False, preferred=False, **kwargs):
+        """
+        Add a email record for the person.
+
+        :param person: Reference to a ``Person`` record.
+        :param address: Actual email address to add.
+        :param type: Type of email address to add.
+        :param invalid: Boolean indicating the address is known to
+           *not* be valid.
+        :param preferred: Boolean indicating that this should (or not)
+           be the "preferred" email address for the person.
+        """
+        email = person.add_email(address=address,
+                                 type=type,
+                                 invalid=invalid)
+        if preferred:
+            person.set_primary_email(email)
+
+        return email
+
+    def update_email(self, person, email, **kwargs):
+        """
+        Update a email record for the person.
+
+        :param person: Reference to a ``Person`` record.
+        :param email: Reference to the ``PersonEmailAddress`` record to update.
+        :param address: Actual email address.
+        :param type: Type of email address.
+        :param invalid: Boolean indicating the address is known to
+           *not* be valid.
+        :param preferred: Boolean indicating that this should (or not)
+           be the "preferred" address for the person.
+        """
+        if email not in person.emails:
+            raise ValueError("Email does not belong to this person.")
+
+        if 'address' in kwargs:
+            email.address = kwargs['address']
+
+        if 'type' in kwargs:
+            email.type = kwargs['type']
+
+        if 'invalid' in kwargs:
+            email.invalid = kwargs['invalid']
+
+        if 'preferred' in kwargs:
+            if kwargs['preferred']:
+                person.set_primary_email(email)
+            else: # should *not* prefer this one
+                if email.preferred and len(person.emails) > 1:
+                    # make 2nd email the new 1st
+                    person.set_primary_email(person.emails[1])
+
+        return email
+
     def ensure_address(self, person, **kwargs):
         """
         Returns the default address record associated with the given
@@ -121,6 +231,27 @@ class PeopleHandler(GenericHandler):
             # person.set_primary_address(address)
         return address
 
+    def address_is_invalid(self, person, address, **kwargs):
+        """
+        Returns a boolean indicating if the given person's address is
+        invalid.
+
+        :param person: Reference to a person.
+        :param address: Reference to a person's address.
+        """
+        return address.invalid
+
+    def mark_address_invalid(self, person, address, invalid, **kwargs):
+        """
+        Mark the person's address as invalid.
+
+        :param person: Reference to a person.
+        :param address: Reference to a person's address.
+        :param invalid: Boolean indicating "invalid" status for
+           person's address.
+        """
+        address.invalid = invalid
+
     def request_merge(self, user, removing_uuid, keeping_uuid, **kwargs):
         """
         Submit an officical merge request for two Person records.
