@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -29,6 +29,7 @@ from __future__ import unicode_literals, absolute_import
 import datetime
 import sys
 import logging
+import warnings
 
 import sqlalchemy as sa
 
@@ -74,13 +75,78 @@ class ImportToTrainwreck(commands.ImportSubcommand):
 
     def get_handler_factory(self, **kwargs):
         if self.config:
-            spec = self.config.get('rattail.trainwreck.importing', '{}.handler'.format(self.handler_key),
+            spec = self.config.get('trainwreck.importing', '{}.handler'.format(self.handler_key))
+            if not spec:
+                spec = self.config.get('rattail.trainwreck.importing', '{}.handler'.format(self.handler_key))
+                if spec:
+                    warnings.warn(("Handler override uses deprecated config.  "
+                                   "Please change the setting name used, from "
+                                   "`[rattail.trainwreck.importing] {0}.handler` "
+                                   "to `[trainwreck.importing] {0}.handler`")\
+                                  .format(self.handler_key), DeprecationWarning)
+                else:
+                    spec = self.default_handler_spec
+        else:
+            # just use default, for sake of cmd line help
+            spec = self.default_handler_spec
+        return load_object(spec)
+
+
+class ExportTrainwreck(commands.ImportSubcommand):
+    """
+    Export data to another Trainwreck database
+    """
+    name = 'export-trainwreck'
+    description = __doc__.strip()
+    default_handler_spec = 'rattail.trainwreck.importing.trainwreck:FromTrainwreckToTrainwreckExport'
+
+    def get_handler_factory(self, **kwargs):
+        if self.config:
+            spec = self.config.get('trainwreck.exporting', 'trainwreck.handler',
                                    default=self.default_handler_spec)
         else:
             # just use default, for sake of cmd line help
             spec = self.default_handler_spec
         return load_object(spec)
 
+    def add_parser_args(self, parser):
+        super(ExportTrainwreck, self).add_parser_args(parser)
+        parser.add_argument('--dbkey', metavar='KEY',
+                            help="Config key for database engine to be used as the \"target\" "
+                            "Trainwreck DB, i.e. where data will be exported.  This key must "
+                            "be defined in the [trainwreck.db] section of your config file.")
+
+    def get_handler_kwargs(self, **kwargs):
+        if 'args' in kwargs:
+            kwargs['dbkey'] = kwargs['args'].dbkey
+        return kwargs
+
+
+class ImportTrainwreck(ImportToTrainwreck):
+    """
+    Import data from another Trainwreck database
+    """
+    name = 'import-trainwreck'
+    description = __doc__.strip()
+    handler_key = 'trainwreck'
+    default_handler_spec = 'rattail.trainwreck.importing.trainwreck:FromTrainwreckToTrainwreckImport'
+    accepts_dbkey_param = True
+
+    def add_parser_args(self, parser):
+        super(ImportTrainwreck, self).add_parser_args(parser)
+
+        if self.accepts_dbkey_param:
+            parser.add_argument('--dbkey', metavar='KEY',
+                                help="Config key for database engine to be used as the Trainwreck "
+                                "\"host\", i.e. the source of the data to be imported.  This key "
+                                "must be defined in the [trainwreck.db] section of your config file.")
+
+    def get_handler_kwargs(self, **kwargs):
+        if self.accepts_dbkey_param:
+            if 'args' in kwargs:
+                kwargs['dbkey'] = kwargs['args'].dbkey
+        return kwargs
+
 
 class Prune(commands.Subcommand):
     """
